/*
Gwenview - A simple image viewer for KDE
Copyright (C) 2000-2001 Aurlien Gteau

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/
// Qt includes
#include <qcheckbox.h>
#include <qspinbox.h>

// KDE includes
#include <kdirsize.h>
#include <kfiledialog.h>
#include <klocale.h>
#include <kio/global.h>
#include <kmessagebox.h>
#include <kurlrequester.h>

// Our includes
#include "filethumbnailview.h"
#include "filewidget.h"
#include "fullscreenwidget.h"
#include "mainwindow.h"
#include "pixmapwidget.h"
#include "thumbnailloadjob.h"

#include "configdialog.moc"


ConfigDialog::ConfigDialog(QWidget* parent,MainWindow* mainWindow)
: ConfigDialogBase(parent,0L,true),
mMainWindow(mainWindow)
{
	FileWidget* fileWidget=mMainWindow->fileWidget();

	mThumbnailMargin->setValue(fileWidget->fileThumbnailView()->marginSize());
	mWordWrapFilename->setChecked(fileWidget->fileThumbnailView()->wordWrapIconText());

	mConfirmBeforeDelete->setChecked(fileWidget->confirmDelete());
	mShowCopyDialog->setChecked(fileWidget->confirmCopy());

	mDefaultCopyFolder->setURL(fileWidget->copyToFolder());
	mDefaultCopyFolder->fileDialog()->setMode(
		static_cast<KFile::Mode>(KFile::Directory | KFile::ExistingOnly | KFile::LocalOnly));

	mShowMoveDialog->setChecked(fileWidget->confirmMove());
	mDefaultMoveFolder->setURL(fileWidget->moveToFolder());
	mDefaultMoveFolder->fileDialog()->setMode(
		static_cast<KFile::Mode>(KFile::Directory | KFile::ExistingOnly | KFile::LocalOnly));

	mZoomStep->setValue(int(mMainWindow->zoomStep()*100));

	connect(mCalculateCacheSize,SIGNAL(clicked()),
		this,SLOT(calculateCacheSize()));
	connect(mEmptyCache,SIGNAL(clicked()),
		this,SLOT(emptyCache()));

	mShowPathInFullScreen->setChecked(mMainWindow->pixmapWidget()->fullScreenWidget()->showPath());
}


void ConfigDialog::slotOk() {
	slotApply();
	accept();
}


void ConfigDialog::slotApply() {
	FileWidget* fileWidget=mMainWindow->fileWidget();

	fileWidget->fileThumbnailView()->setMarginSize(mThumbnailMargin->value());
	fileWidget->fileThumbnailView()->setWordWrapIconText(mWordWrapFilename->isChecked());
	fileWidget->fileThumbnailView()->arrangeItemsInGrid();

	fileWidget->setConfirmDelete(mConfirmBeforeDelete->isChecked());
	fileWidget->setConfirmCopy(mShowCopyDialog->isChecked());
	fileWidget->setCopyToFolder(mDefaultCopyFolder->url());
	fileWidget->setConfirmMove(mShowMoveDialog->isChecked());
	fileWidget->setMoveToFolder(mDefaultMoveFolder->url());

	mMainWindow->setZoomStep(mZoomStep->value()/100.0);

	mMainWindow->pixmapWidget()->fullScreenWidget()->setShowPath(mShowPathInFullScreen->isChecked());
}


void ConfigDialog::calculateCacheSize() {
	KURL url;
	url.setPath(ThumbnailLoadJob::thumbnailDir());
	unsigned long size=KDirSize::dirSize(url);
	KMessageBox::information( this,i18n("Cache size is %1").arg(KIO::convertSize(size)) );
}


void ConfigDialog::emptyCache() {
	QString dir=ThumbnailLoadJob::thumbnailDir();
	int response=KMessageBox::questionYesNo(this,i18n("Are you sure you want to empty the thumbnail cache ?"
		" This will remove the folder <b>%1</b>.").arg(dir));

	if (response==KMessageBox::No) return;

	KURL url;
	url.setPath(dir);
	KIO::DeleteJob* job=KIO::del(url);
	connect(job,SIGNAL(result(KIO::Job*)),
		this,SLOT(onCacheEmptied(KIO::Job*)));
}


void ConfigDialog::onCacheEmptied(KIO::Job* job) {
	if ( job->error() ) {
		job->showErrorDialog(this);
		return;
	}
	KMessageBox::information( this,i18n("Cache emptied") );
}
