/*
Gwenview - A simple image viewer for KDE
Copyright (C) 2000-2001 Aurlien Gteau

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/


// KDE includes
#include <kapp.h>
#include <kio/job.h>
#include <kio/jobclasses.h>
#include <kio/netaccess.h>
#include <klocale.h>
#include <kmessagebox.h>

// Our includes
#include "fileoperation.moc"



//-Public----------------------------------------------------------
void FileOperation::fileCopy(const KURL& src,const KURL& dst,QWidget* parent) {
	FileOperation* op=new FileOperation(parent);
	if (!op->checkOverwrite(dst)) {
		delete op;
		return;
	}

	KIO::Job* copyJob=KIO::file_copy(src,dst,-1,true);
	connect( copyJob, SIGNAL( result(KIO::Job*) ),
		op, SLOT( slotResult(KIO::Job*) ) );
}


void FileOperation::fileMove(const KURL& src,const KURL& dst,QWidget* parent) {
	FileOperation* op=new FileOperation(parent);
	if (!op->checkOverwrite(dst)) {
		delete op;
		return;
	}

	KIO::Job* moveJob=KIO::file_move(src,dst,-1,true);
	connect( moveJob, SIGNAL( result(KIO::Job*) ),
		op, SLOT( slotResult(KIO::Job*) ) );
}


void FileOperation::fileDelete(const KURL& url,QWidget* parent) {
	FileOperation* op=new FileOperation(parent);
	KIO::Job* removeJob=KIO::file_delete(url,true);

	connect( removeJob, SIGNAL( result(KIO::Job*) ),
		op, SLOT( slotResult(KIO::Job*) ) );
}


//-Private---------------------------------------------------------
FileOperation::FileOperation(QWidget* parent)
: mParent(parent)
{}


void FileOperation::slotResult(KIO::Job* job) {
	if (job->error()) {
		job->showErrorDialog(mParent);
	}

// Let's shoot ourself in the foot...
	delete this;
}


void FileOperation::slotStatResult(KIO::Job* job) {
	if (job->error()) {
		mExists=NO;
	} else {
		mExists=YES;
	}
}


bool FileOperation::checkOverwrite(const KURL& url) {
// Check that the file exists
	mExists=UNKNOWN;
	KIO::Job* job = KIO::stat(url,false);
	connect(job, SIGNAL(result(KIO::Job*) ),
		this, SLOT(slotStatResult(KIO::Job*)) );
	while (mExists==UNKNOWN) {
		kapp->processOneEvent();
	}

// Doesn't exist, return true
	if (mExists==NO) return true;

// Prompt for overwrite
	int response;
	response=KMessageBox::questionYesNo(
		mParent,
		i18n("File <b>%1</b> already exists. Do you want to overwrite it ?").arg(url.url()));
	return response==KMessageBox::Yes;
}
