/*
Gwenview - A simple image viewer for KDE
Copyright (C) 2000-2001 Aurlien Gteau

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/
#ifndef FILEWIDGET_H
#define FILEWIDGET_H

#include <qobject.h>
#include <qwidgetstack.h>

#include <kfileview.h>

class QIconViewItem;
class QListViewItem;

class KConfig;

class FileDnDDetailView;
class FileThumbnailView;
class ImageFileReader;



class FileWidget : public QWidgetStack {
Q_OBJECT

public:
	enum Mode { FileList, Thumbnail};

	FileWidget(QWidget* parent,Mode);
	~FileWidget();

	void readConfig(KConfig*,const QString&);
	void writeConfig(KConfig*,const QString&) const;

	void setMode(Mode);

	void setConfirmDelete(bool);
	void setConfirmCopy(bool);
	void setConfirmMove(bool);
	void setCopyToFolder(const QString&);
	void setMoveToFolder(const QString&);

	bool currentIsFirst() const;
	bool currentIsLast() const;
	uint fileCount() const;
	QString filename() const { return mFilename; }
	bool confirmDelete() const { return mConfirmDelete; }
	bool confirmCopy() const { return mConfirmCopy; }
	bool confirmMove() const { return mConfirmMove; }
	QString copyToFolder() const { return mCopyToFolder; }
	QString moveToFolder() const { return mMoveToFolder; }
	FileThumbnailView* fileThumbnailView() const { return mFileThumbnailView; }

public slots:
	void setFolderAndFile(QString folder,QString filename);

	void selectFilename(QString filename);
	void selectFirst();
	void selectLast();
	void selectPrevious();
	void selectNext();

	void cancel();

	/**
	 * Deletes the currently selected file
	 */
	void deleteFile();

	/**
	 * Rename the current file
	 */
	void renameFile();

	/**
	 * Copy the current file
	 */
	void copyFile();

	/**
	 * Move the current file
	 */
	void moveFile();


signals:
	void filenameChanged(QString filename);
	void completed();
	void canceled();

private slots:
	/**
	 * Connected to detail view signal
	 */
	void detailChanged(QListViewItem* item);

	/**
	 * Connected to thumbnail view signal
	 */
	void thumbnailChanged(QIconViewItem* item);

	/**
	 * Connected to the job handling the rename
	 */
	void slotRenamed(KIO::Job*);



// Image file reader slots
	void removeItem(KFileItem* item);
	void newItems(const KFileItemList& items);
	void fileReaderCanceled();
	void fileReaderCompleted();
	void clear();
	void stopFileReader();

private:
	Mode mMode;
	FileDnDDetailView* mFileDetailView;
	FileThumbnailView* mFileThumbnailView;
	ImageFileReader* mFileReader;
	QString mFolder;
	QString mFilename;
	QString mNewFilename; // File name used by slotRenamed

	/**
	 * This function selects mFilename,
	 * it does not emit any signal
	 */
	void selectFilenameInternal();
	KFileView* currentFileView() const;

	/**
	 * configurable settings
	 */
	bool mConfirmMove;
	QString mMoveToFolder;

	bool mConfirmCopy;
	QString mCopyToFolder;

	bool mConfirmDelete;
};


#endif
