/*
Gwenview - A simple image viewer for KDE
Copyright (C) 2000-2001 Aurlien Gteau

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/


// QT includes
#include <qdir.h>

// KDE includes
#include <kdebug.h>
#include <kdirlister.h>

// Our includes
#include "folderwidget.h"
#include "folderwidgetitem.h"


FolderWidgetItem::FolderWidgetItem(FolderWidget* folderWidget, const QString& label, const KURL& url)
: QListViewItem(folderWidget,label), mFolderWidget(folderWidget), mURL(url)
{
	setPixmap(0,SmallIcon("folder"));
}


FolderWidgetItem::FolderWidgetItem(FolderWidget* folderWidget,QListViewItem* parent,const QString& label,const KURL& url)
: QListViewItem(parent,label), mFolderWidget(folderWidget), mURL(url)
{
	setPixmap(0,SmallIcon("folder"));
}


/**
 * Find a sub item according to its label
 * ! Assumes that the item tree as already been explored !
 */
FolderWidgetItem* FolderWidgetItem::find(const QString& label) const {
	QListViewItem* child=firstChild();

	while(child) {
		if (child->text(0)==label) {
			return static_cast<FolderWidgetItem*>(child);
		}
		child=child->nextSibling();
	}

	return 0L;
}


/**
 * Override setOpen so that if the folder is not explored, we explore it
 * before calling the original implementation.
 */
void FolderWidgetItem::setOpen(bool open) {
	QListViewItem::setOpen(open);
	if (open) {
		mFolderWidget->mDirLister->openURL(mURL,true,true);
	}
}


/**
 * Starts a job to determine if the item should be expandable or not
 * (ie if it contains at least one dir)
 */
void FolderWidgetItem::initExpandable() {
	QString folder=mURL.path();
	QFileInfo info(folder);
	if (!info.isReadable()) {
		setPixmap(0,SmallIcon("folder_locked"));
		return;
	}

	QDir dir(folder);
	QStringList dirs=dir.entryList(QDir::Dirs,QDir::Unsorted);
	dirs.remove(".");
	dirs.remove("..");
	if (dirs.count()>0) {
		setExpandable(true);
	}
}


void FolderWidgetItem::setURL(const KURL& url) {
	mURL=url;
	setText(0,mURL.filename());
}

