/*
Gwenview - A simple image viewer for KDE
Copyright (C) 2000-2001 Aurlien Gteau

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/
#ifndef MAINWINDOW_H
#define MAINWINDOW_H


#include <kdockwidget.h>


class KAction;
class KAccel;
class KRadioAction;

class FileWidget;
class FolderWidget;
class GVPixmap;
class PixmapWidget;
class StatusBarProgress;


class MainWindow : public KDockMainWindow {
Q_OBJECT
public:
	MainWindow();
	~MainWindow();

	void setZoomStep(double value);
	double zoomStep() const;

	FileWidget* fileWidget() const { return mFileWidget; }
	PixmapWidget* pixmapWidget() const { return mPixmapWidget; }

public slots:
	void setPath(QString);
	void setFilename(QString);

private:
	KDockWidget* mFolderDock;
	KDockWidget* mFileDock;
	KDockWidget* mPixmapDock;
	StatusBarProgress* mProgress;

	FileWidget* mFileWidget;
	FolderWidget* mFolderWidget;
	PixmapWidget* mPixmapWidget;

	bool mStartWithThumbnails;
	bool mFullScreen;
	double mZoomStep;
	QString mFolder,mFilename;
	GVPixmap* mGVPixmap;

	KAction* mOpenFile;
	KAction* mRenameFile;
	KAction* mCopyFile;
	KAction* mMoveFile;
	KAction* mDeleteFile;
	KAction* mSelectFirst;
	KAction* mSelectLast;
	KAction* mSelectPrevious;
	KAction* mSelectNext;
	KAction* mShowConfigDialog;
	KAction* mShowKeyDialog;
	KAction* mToggleFullScreen;
	KRadioAction* mNoThumbnails;
	KRadioAction* mSmallThumbnails;
	KRadioAction* mMedThumbnails;
	KRadioAction* mLargeThumbnails;
	KAction* mZoomIn;
	KAction* mZoomOut;
	KAction* mResetZoom;
	KAction* mStop;
	KAccel* mAccel;

	void createWidgets();
	void createActions();
	void createAccels();
	void createMenu();
	void createToolBar();
	void updateZoomGUI();

private slots:
	void openFile();
	void setThumbnailSize();
	void toggleFullScreen();
	void showConfigDialog();
	void showKeyDialog();
	void zoomIn();
	void zoomOut();
	void resetZoom();
	void pixmapLoading();
	void pixmapLoaded();

	/**
	 * Update both folder and file status bar
	 */
	void updateStatusBar();

	/**
	 * Update only file status bar, allows setting file info
	 * when folder info is not available yet
	 */
	void updateFileStatusBar();

	void thumbnailUpdateStarted(int);
	void thumbnailUpdateEnded();
	void thumbnailUpdateProcessedOne();

	/**
	 * Allow quitting full screen mode by pressing Escape key.
	 */
	void escapePressed();
};


#endif
