/*
Gwenview - A simple image viewer for KDE
Copyright (C) 2000-2001 Aurlien Gteau

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

// QT includes
#include <qpixmap.h>
#include <qpainter.h>

// KDE includes
#include <kdebug.h>

// Our includes
#include "fullscreenwidget.h"
#include "gvpixmap.h"
#include "scrollpixmapwidget.h"

#include "pixmapwidget.moc"



PixmapWidget::PixmapWidget(QWidget* parent,GVPixmap* pixmap)
: QWidgetStack(parent), mFullScreen(false)
{
// Create child widgets
	mScrollPixmapWidget=new ScrollPixmapWidget(this,pixmap,true);
	mScrollPixmapWidget->setScale(1);
	mFullScreenWidget=new FullScreenWidget(this,pixmap,false);

// Propagate child widget signals
	connect(mScrollPixmapWidget,SIGNAL(selectPrevious()),
		this,SIGNAL(selectPrevious()) );
	connect(mScrollPixmapWidget,SIGNAL(selectNext()),
		this,SIGNAL(selectNext()) );

	connect(mFullScreenWidget,SIGNAL(selectPrevious()),
		this,SIGNAL(selectPrevious()) );
	connect(mFullScreenWidget,SIGNAL(selectNext()),
		this,SIGNAL(selectNext()) );

// Add children to stack
	addWidget(mScrollPixmapWidget,0);
	addWidget(mFullScreenWidget,1);

// Show scroll pixmap widget by default
	raiseWidget(mScrollPixmapWidget);
}


PixmapWidget::~PixmapWidget() {
}


void PixmapWidget::readConfig(KConfig* config, const QString& group) {
	mFullScreenWidget->readConfig(config,group);	
}


void PixmapWidget::writeConfig(KConfig* config, const QString& group) const {
	mFullScreenWidget->writeConfig(config,group);	
}


void PixmapWidget::setFullScreen(bool fullScreen) {
	mFullScreen=fullScreen;
	if (mFullScreen) {
		mScrollPixmapWidget->enableView(false);
		raiseWidget(mFullScreenWidget);
		mFullScreenWidget->enableView(true);
		mFullScreenWidget->updateView();
	} else {
		mFullScreenWidget->enableView(false);
		raiseWidget(mScrollPixmapWidget);
		mScrollPixmapWidget->enableView(true);
		mScrollPixmapWidget->updateView();
	}
}


double PixmapWidget::scale() const {
	return mScrollPixmapWidget->scale();
}


void PixmapWidget::setScale(double scale) {
	mScrollPixmapWidget->setScale(scale);
}


