/*
Gwenview - A simple image viewer for KDE
Copyright (C) 2000-2001 Aurlien Gteau

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

// QT includes
#include <qpixmap.h>
#include <qpainter.h>
#include <qevent.h>

// Our includes
#include "gvpixmap.h"

#include "scrollpixmapwidget.moc"

ScrollPixmapWidget::ScrollPixmapWidget(QWidget* parent,GVPixmap* pixmap,bool enabled)
: QScrollView(parent), mGVPixmap(pixmap), mScale(1)
{
	enableView(enabled);
}


void ScrollPixmapWidget::enableView(bool enabled) {
	disconnect(mGVPixmap,0,this,0);

	if (enabled) {
		connect(mGVPixmap,SIGNAL(loaded()),
			this,SLOT(updateView()) );
	}
}


void ScrollPixmapWidget::updateView() {
	if (mGVPixmap->isNull()) {
		resizeContents(0,0);
	} else {
		mScale=1.0;
		resizeContents( mGVPixmap->pixmap().width(), mGVPixmap->pixmap().height() );
		horizontalScrollBar()->setValue(0);
		verticalScrollBar()->setValue(0);
	}
	viewport()->repaint(true);
}


void ScrollPixmapWidget::setScale(double scale) {
	if (mScale==scale) {
		return;
	}
	mScale=scale;
	resizeContents(
		int(mGVPixmap->pixmap().width()*mScale),
		int(mGVPixmap->pixmap().height()*mScale) );
	viewport()->repaint(true);
}


//-Private---------------------------------------------------------------------
void ScrollPixmapWidget::drawContents(QPainter* painter,int clipx,int clipy,int clipw,int cliph) {
	if (mGVPixmap->isNull()) {
		painter->eraseRect(clipx,clipy,clipw,cliph);
	} else {
		painter->scale(mScale,mScale);
		painter->drawPixmap( int(clipx/mScale),int(clipy/mScale),
			mGVPixmap->pixmap(),
			int(clipx/mScale)-1,int(clipy/mScale)-1,
			int(clipw/mScale)+2,int(cliph/mScale)+2 );
	}
}


void ScrollPixmapWidget::viewportMousePressEvent(QMouseEvent* event) {
	mScrollStartX=event->x();
	mScrollStartY=event->y();
	setCursor(QCursor(SizeAllCursor));
}


void ScrollPixmapWidget::viewportMouseMoveEvent(QMouseEvent* event) {
	int deltaX,deltaY;

	deltaX=mScrollStartX - event->x();
	deltaY=mScrollStartY - event->y();

	mScrollStartX=event->x();
	mScrollStartY=event->y();
	scrollBy(deltaX,deltaY);
}


void ScrollPixmapWidget::viewportMouseReleaseEvent(QMouseEvent* event) {
	setCursor(QCursor(ArrowCursor));

	switch (event->button()) {
	case Qt::LeftButton:
		if (event->stateAfter() & Qt::RightButton) {
			emit selectPrevious();
		}
		return;
	case Qt::RightButton:
		if (event->stateAfter() & Qt::LeftButton) {
			emit selectNext();
		}
		return;
	default:
		break;
	}
}


void ScrollPixmapWidget::wheelEvent(QWheelEvent* event) {
	if (! (event->state() & Qt::ControlButton) ) {
		QScrollView::wheelEvent(event);
		return;
	}

	if (event->delta()<0) {
		emit selectNext();
	} else {
		emit selectPrevious();
	}
	event->accept();
}
